CLI
---

Problematic
^^^^^^^^^^^

How can we easily work and distribute some CLI related logic?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.cli
   :members:
   :private-members:


:code:`Dispatcher()`
""""""""""""""""""""

.. autoclass:: PyFunceble.cli.dispatcher.Dispatcher
    :members:
    :private-members:

:code:`ExecutionTime()`
"""""""""""""""""""""""

.. autoclass:: PyFunceble.cli.execution_time.ExecutionTime
    :members:
    :private-members: